@@ -3,20 +3,7 @@ use crate::dialects::builtin::traits::{ProvidesSymbol, ProvidesSymbolTable};
 use crate::*;
 
 // Module intrinsic.
-#[derive(Copy, Clone, PartialEq, Eq, PartialOrd, Ord, Debug)]
-pub struct Module;
-
-impl Intrinsic for Module {
-    fn get_namespace(&self) -> &str {
-        "builtin"
-    }
-
-    fn get_name(&self) -> &str {
-        "module"
-    }
-}
-
-impl ProvidesSymbolTable for Module {}
+intrinsic!(Module, "builtin", "module", ProvidesSymbolTable);
 
 impl Module {
     pub fn get_builder(&self, name: &str, loc: LocationInfo) -> OperationBuilder {
@@ -34,27 +21,8 @@ impl Module {
     }
 }
 
-interfaces!(
-    Module: dyn ObjectClone,
-    dyn Intrinsic,
-    dyn ProvidesSymbolTable
-);
-
-// Function operation.
-#[derive(Copy, Clone, PartialEq, Eq, PartialOrd, Ord, Debug)]
-pub struct Func;
-
-impl Intrinsic for Func {
-    fn get_namespace(&self) -> &str {
-        "builtin"
-    }
-
-    fn get_name(&self) -> &str {
-        "func"
-    }
-}
-
-impl ProvidesSymbol for Func {}
+// Function intrinsic.
+intrinsic!(Func, "builtin", "func", ProvidesSymbol);
 
 impl Func {
     pub fn get_builder(&self, name: &str, loc: LocationInfo) -> OperationBuilder {
@@ -69,5 +37,3 @@ impl Func {
         b
     }
 }
-
-interfaces!(Func: dyn ObjectClone, dyn Intrinsic, dyn ProvidesSymbol);
