@@ -1,6 +1,8 @@
 #![doc = include_str!("../README.md")]
+#![warn(missing_docs)]
+#![warn(rustdoc::missing_doc_code_examples)]
 
-//pub mod backends;
+pub mod backends;
 pub mod dialects;
 
 mod core;
@@ -14,3 +16,5 @@ extern crate tracing_subscriber;
 
 #[macro_use]
 extern crate lazy_static;
+
+pub use color_eyre::{eyre::bail, Report};
